# CrudDB

The [CrudDB][fluid.db.CrudDB] class inherits from [Database][fluid.db.Database] to
provide standard CRUD operations for a database table.

It requires the `db` extra to be installed:

```bash
pip install aio-fluid[db]
```

It can be imported from `fluid.db`:

```python
from fluid.db import CrudDB
```

::: fluid.db.CrudDB
